@@ -18,7 +18,7 @@ def do_discover(config):
     '''
     Run the discovery mode for each streams
     '''
-    LOGGER.info("Starting discover version updated")
+    LOGGER.info("Starting discover")
     streams = discover_streams(config)
     if not streams:
         raise Exception("No streams found")
@@ -56,7 +56,7 @@ def do_sync(config, catalog, state):
         counts[stream_name] = sync_stream(config, state, stream)
         sync_times[stream_name] = time.time() - start_time
         LOGGER.info("%s: Completed sync (%s rows)", stream_name, counts[stream_name])
-
+    LOGGER.info("state saving to file got here :",state)
     LOGGER.info(get_sync_summary(catalog, counts, sync_times))
     LOGGER.info('Done syncing.')
 
