@@ -85,7 +85,8 @@ def sync_shard(shard, seq_number_bookmarks, streams_client, stream_arn, projecti
 
     for record in get_shard_records(streams_client, stream_arn, shard, seq_number):
         LOGGER.info("Record got here  : %s",record)
-        if record['dynamodb']['SequenceNumber']==seq_number :
+        LOGGER.info("type of record seq number: %s,%s",type(seq_number),type(record['dynamodb']['SequenceNumber']))
+        if record['dynamodb']['SequenceNumber']<=seq_number :
             LOGGER.info("Skipping sync of shard %s as no records updated",shard['ShardId'])
             continue
         if record['eventName'] == 'REMOVE':
@@ -215,8 +216,6 @@ def sync(config, state, stream):
         state = singer.write_bookmark(state, table_name, 'finished_shards', finished_shard_bookmarks)
         LOGGER.info("got seq_number_bookmarks after sync shard : %s", seq_number_bookmarks)
         if seq_number_bookmarks.get(shard['ShardId']):
-            LOGGER.info("get seq after sync hard :%s",seq_number_bookmarks)
-            seq_number_bookmarks.pop(shard['ShardId'])
             state = singer.write_bookmark(state, table_name, 'shard_seq_numbers', seq_number_bookmarks)
         singer.write_state(state)
 
